Skip to contents

Drops every dataset memoised during the current R session. Useful when iterating during development or to force re-fetch without restarting R.

Usage

clear_session_cache()

Value

NULL, invisibly.

Examples

if (FALSE) { # interactive()
clear_session_cache()
}