| cli_debug | R Documentation |
Displays informational messages only when debug mode is enabled.
This function is a wrapper around cli::cli_inform() that respects
the debug mode setting.
cli_debug(message, ...)
message |
Character string. The message to display. |
... |
Additional arguments passed to |
This function should be used for detailed processing messages that are
useful for development and debugging but would be too verbose for
end-users. Messages are only shown when debug mode is enabled via
is_debug_mode().
is_debug_mode()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.