get_from_github_cache: Get Data from GitHub Release Cache

View source: R/get_dataset.R

get_from_github_cacheR Documentation

Get Data from GitHub Release Cache

Description

Downloads the appropriate asset into a tempfile and returns the deserialised object, applying table filtering where applicable.

Usage

get_from_github_cache(name, dataset_info, table)

realestatebr documentation built on June 5, 2026, 5:07 p.m.