Downloads property transaction records from Registro de Imoveis including capitals, cities, and regional aggregates data.
Deprecation
This function is deprecated since v0.4.0.
Use get_dataset("property_records") instead.
Downloads property transaction records from Registro de Imoveis including capitals, cities, and regional aggregates data.
This function is deprecated since v0.4.0.
Use get_dataset("property_records") instead.