| get_rppi_fipezap | R Documentation |
Get FipeZap RPPI
get_rppi_fipezap(city = "all", quiet = FALSE, max_retries = 3L)
city |
City name or "all" (default). Filtering by city doesn't save processing time. |
quiet |
Logical. If TRUE, suppresses warnings |
max_retries |
Integer. Maximum retry attempts |
The FipeZap Index is a monthly median stratified index across ~20 Brazilian cities,
based on online listings from Zap Imoveis. Includes residential and commercial markets,
both sale and rent, stratified by number of rooms. The overall city index is a weighted
sum of median prices by room/region. Residential index includes only apartments, studios,
and flats. National index: name_muni == 'Brazil' (after standardization).
Tibble with columns: date, name_muni, market, rent_sale, variable, rooms, value
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.