get_rppi_iqa: Get QuintoAndar Rental Index (IQA)

View source: R/get_rppi.R

get_rppi_iqaR Documentation

Get QuintoAndar Rental Index (IQA)

Description

Get QuintoAndar Rental Index (IQA)

Usage

get_rppi_iqa(quiet = FALSE, max_retries = 3L)

Arguments

quiet

Logical. If TRUE, suppresses warnings

max_retries

Integer. Maximum retry attempts for downloads

Details

The IQA (QuintoAndar Rental Index) is a median stratified index for Rio de Janeiro and Sao Paulo, based on new rent contracts managed by QuintoAndar. Includes only apartments, studios, and flats. Note: IQA provides raw prices (not index numbers), so rent_price is the median rent per square meter.

Value

Tibble with columns: date, name_muni, rent_price, chg, acum12m


realestatebr documentation built on June 5, 2026, 5:07 p.m.