| get_secovi | R Documentation |
Import data from Secovi-SP
get_secovi(table = "all", quiet = FALSE, max_retries = 3L)
table |
Character. One of |
quiet |
Logical. If |
max_retries |
Integer. Maximum number of retry attempts for failed web scraping operations. Defaults to 3. |
Scrapes real estate data from SECOVI-SP including condominium fees, rental market data, launches, and sales information.
A tibble with SECOVI-SP real estate data. The return includes
metadata attributes:
List with download statistics
Data source used
Timestamp of download
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.