Returns the path to the user-level cache directory for realestatebr package. This directory is used to store downloaded datasets for faster subsequent access.
Returns the path to the user-level cache directory for realestatebr package. This directory is used to store downloaded datasets for faster subsequent access.