realestatebr-package: realestatebr: Import Brazilian Real Estate Data into R

realestatebr-packageR Documentation

realestatebr: Import Brazilian Real Estate Data into R

Description

Provides access to Brazilian real estate market data from multiple official sources: the Central Bank of Brazil (BCB), the Brazilian Association of Real Estate Developers (ABRAINC), the Brazilian Association of Real Estate Credit and Savings Entities (ABECIP), the Getulio Vargas Foundation (FGV), and the Bank for International Settlements (BIS).

Author(s)

Maintainer: Vinicius Oike Reginatto viniciusoike@gmail.com [copyright holder]

See Also

Useful links:


realestatebr documentation built on June 5, 2026, 5:07 p.m.