clear_session_cache: Clear the In-Session Dataset Memo

View source: R/cache_github.R

clear_session_cacheR Documentation

Clear the In-Session Dataset Memo

Description

Drops every dataset memoised during the current R session. Useful when iterating during development or to force re-fetch without restarting R.

Usage

clear_session_cache()

Value

NULL, invisibly.

Examples


clear_session_cache()


realestatebr documentation built on June 5, 2026, 5:07 p.m.