| clear_session_cache | R Documentation |
Drops every dataset memoised during the current R session. Useful when iterating during development or to force re-fetch without restarting R.
clear_session_cache()
NULL, invisibly.
clear_session_cache()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.