| get_from_github_cache | R Documentation |
Downloads the appropriate asset into a tempfile and returns the deserialised object, applying table filtering where applicable.
get_from_github_cache(name, dataset_info, table)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.