| get_rppi_igmi | R Documentation |
Get the IGMI Sales Index
get_rppi_igmi(quiet = FALSE, max_retries = 3L)
quiet |
Logical. If TRUE, suppresses warnings |
max_retries |
Integer. Maximum retry attempts for downloads |
The IGMI-R (Residential Real Estate Index) is a hedonic sales index based on bank appraisal reports, available for Brazil + 10 capital cities. Hedonic indices account for both composition bias and quality differentials across the housing stock. Maintained by ABECIP in partnership with FGV.
Tibble with columns: date, name_muni, index, chg, acum12m
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.