| get_rppi_iqa | R Documentation |
Get QuintoAndar Rental Index (IQA)
get_rppi_iqa(quiet = FALSE, max_retries = 3L)
quiet |
Logical. If TRUE, suppresses warnings |
max_retries |
Integer. Maximum retry attempts for downloads |
The IQA (QuintoAndar Rental Index) is a median stratified index for Rio de Janeiro
and Sao Paulo, based on new rent contracts managed by QuintoAndar. Includes only
apartments, studios, and flats. Note: IQA provides raw prices (not index numbers),
so rent_price is the median rent per square meter.
Tibble with columns: date, name_muni, rent_price, chg, acum12m
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.