| realestatebr-package | R Documentation |
Provides access to Brazilian real estate market data from multiple official sources: the Central Bank of Brazil (BCB), the Brazilian Association of Real Estate Developers (ABRAINC), the Brazilian Association of Real Estate Credit and Savings Entities (ABECIP), the Getulio Vargas Foundation (FGV), and the Bank for International Settlements (BIS).
Maintainer: Vinicius Oike Reginatto viniciusoike@gmail.com [copyright holder]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.